@@ -112,6 +112,7 @@ export class HistoryAppElement extends HistoryAppElementBase {
             // The id of the currently selected page.
             selectedPage_: { type: String },
             queryResult_: { type: Object },
+            sessionList_: { type: Array },
             // Updated on synced-device-manager attach by chrome.sending
             // 'otherDevicesInitialized'.
             signInState_: {
@@ -183,12 +184,14 @@ export class HistoryAppElement extends HistoryAppElementBase {
     get pendingDelete_() { return this.#pendingDelete__accessor_storage; }
     set pendingDelete_(value) { this.#pendingDelete__accessor_storage = value; }
     #queryResult__accessor_storage = {
-        info: undefined,
+        info: null,
         value: [],
-        sessionList: [],
     };
     get queryResult_() { return this.#queryResult__accessor_storage; }
     set queryResult_(value) { this.#queryResult__accessor_storage = value; }
+    #sessionList__accessor_storage = [];
+    get sessionList_() { return this.#sessionList__accessor_storage; }
+    set sessionList_(value) { this.#sessionList__accessor_storage = value; }
     #queryState__accessor_storage = {
         incremental: false,
         querying: false,
@@ -512,7 +515,7 @@ export class HistoryAppElement extends HistoryAppElementBase {
      *     devices.
      */
     setForeignSessions_(sessionList) {
-        this.queryResult_ = Object.assign({}, this.queryResult_, { sessionList });
+        this.sessionList_ = sessionList;
     }
     /**
      * Updates the sign-in state.
