@@ -2,7 +2,7 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 import{html}from"//resources/lit/v3_0/lit.rollup.js";export function getHtml(){return html`<!--_html_template_start_-->
-  <div class="cr-centered-card-container class="flex">
+  <div class="cr-centered-card-container" class="flex">
     <h2>$i18n{privateStateTokensHeadingLabel}</h2>
     <div class="flex">
       <p class="inline-text cr-secondary-text">
