@@ -15,13 +15,14 @@ export function getTemplate() {
 
   <template is="dom-if" if="[[showPage_(pageVisibility_.safetyHub)]]">
     <template is="dom-if" if="[[renderView_(
-        routes_.PRIVACY, currentRoute, inSearchMode)]]">
+        routes_.PRIVACY, currentRoute, inSearchMode)]]" update-when-false>
       <settings-safety-hub-entry-point slot="view" id="safetyHubEntryPoint">
       </settings-safety-hub-entry-point>
     </template>
 
     <template is="dom-if" if="[[renderView_(
-        routes_.SAFETY_HUB, currentRoute, inSearchMode)]]">
+        routes_.SAFETY_HUB, currentRoute, inSearchMode)]]"
+        update-when-false>
       <!-- TODO(crbug.com/40267370): Make the page searchable.-->
       <settings-safety-hub-page slot="view" id="safetyHub" no-search
           data-parent-view-id="safetyHubEntryPoint" prefs="{{prefs}}"
@@ -30,7 +31,8 @@ export function getTemplate() {
     </template>
   </template>
 
-  <template is="dom-if" if="[[renderPrivacyView_(currentRoute, inSearchMode)]]">
+  <template is="dom-if" if="[[renderPrivacyView_(currentRoute, inSearchMode)]]"
+      update-when-false>
     <settings-privacy-page slot="view" id="privacy" prefs="{{prefs}}"
         route-path$="[[routes_.PRIVACY.path]]">
     </settings-privacy-page>
@@ -38,7 +40,8 @@ export function getTemplate() {
 
   <template is="dom-if" if="[[isAdPrivacyAvailable_]]" restamp>
     <template is="dom-if" if="[[renderView_(
-        routes_.PRIVACY_SANDBOX, currentRoute, inSearchMode)]]">
+        routes_.PRIVACY_SANDBOX, currentRoute, inSearchMode)]]"
+        update-when-false>
       <settings-privacy-sandbox-page slot="view" id="privacySandbox"
           data-parent-view-id="privacy" prefs="{{prefs}}"
           route-path$="[[routes_.PRIVACY_SANDBOX.path]]">
@@ -46,7 +49,8 @@ export function getTemplate() {
     </template>
 
     <template is="dom-if" if="[[renderView_(
-        routes_.PRIVACY_SANDBOX_AD_MEASUREMENT, currentRoute, inSearchMode)]]">
+        routes_.PRIVACY_SANDBOX_AD_MEASUREMENT, currentRoute, inSearchMode)]]"
+        update-when-false>
       <settings-privacy-sandbox-ad-measurement-subpage slot="view"
           id="privacySandboxAdMeasurement" data-parent-view-id="privacy"
           prefs="{{prefs}}"
@@ -57,7 +61,8 @@ export function getTemplate() {
 
   <template is="dom-if" if="[[!isPrivacySandboxRestricted_]]" restamp>
     <template is="dom-if" if="[[renderView_(
-        routes_.PRIVACY_SANDBOX_FLEDGE, currentRoute, inSearchMode)]]">
+        routes_.PRIVACY_SANDBOX_FLEDGE, currentRoute, inSearchMode)]]"
+        update-when-false>
       <settings-privacy-sandbox-fledge-subpage slot="view"
           id="privacySandboxFledge" data-parent-view-id="privacy"
           prefs="{{prefs}}"
@@ -66,7 +71,8 @@ export function getTemplate() {
     </template>
 
     <template is="dom-if" if="[[renderView_(
-          routes_.PRIVACY_SANDBOX_TOPICS, currentRoute, inSearchMode)]]">
+          routes_.PRIVACY_SANDBOX_TOPICS, currentRoute, inSearchMode)]]"
+          update-when-false>
       <settings-privacy-sandbox-topics-subpage slot="view"
           id="privacySandboxTopics" data-parent-view-id="privacy"
           prefs="{{prefs}}"
@@ -75,7 +81,8 @@ export function getTemplate() {
     </template>
 
     <template is="dom-if" if="[[renderView_(
-          routes_.PRIVACY_SANDBOX_MANAGE_TOPICS, currentRoute, inSearchMode)]]">
+          routes_.PRIVACY_SANDBOX_MANAGE_TOPICS, currentRoute, inSearchMode)]]"
+          update-when-false>
       <settings-privacy-sandbox-manage-topics-subpage slot="view"
           id="privacySandboxManageTopics" data-parent-view-id="privacy"
           prefs="{{prefs}}"
@@ -87,7 +94,8 @@ export function getTemplate() {
   <!-- Keep entries below sorted based on the route name. -->
 
   <template is="dom-if" if="[[renderView_(
-      routes_.COOKIES, currentRoute, inSearchMode)]]">
+      routes_.COOKIES, currentRoute, inSearchMode)]]"
+      update-when-false>
     <settings-cookies-page slot="view" id="cookies"
         data-parent-view-id="privacy" prefs="{{prefs}}"
         route-path$="[[routes_.COOKIES.path]]">
@@ -96,7 +104,8 @@ export function getTemplate() {
 
   <template is="dom-if" if="[[enableIncognitoTrackingProtections_]]">
     <template is="dom-if" if="[[renderView_(
-        routes_.INCOGNITO_TRACKING_PROTECTIONS, currentRoute, inSearchMode)]]">
+        routes_.INCOGNITO_TRACKING_PROTECTIONS, currentRoute, inSearchMode)]]"
+        update-when-false>
       <incognito-tracking-protections-page slot="view"
           id="incognitoTrackingProtections" data-parent-view-id="privacy"
           prefs="{{prefs}}"
@@ -107,7 +116,7 @@ export function getTemplate() {
 
   <template is="dom-if" if="[[!enableBundledSecuritySettings_]]">
     <template is="dom-if" if="[[renderView_(
-        routes_.SECURITY, currentRoute, inSearchMode)]]">
+        routes_.SECURITY, currentRoute, inSearchMode)]]" update-when-false>
       <settings-security-page slot="view"
           id="security" data-parent-view-id="privacy" prefs="{{prefs}}"
           route-path$="[[routes_.SECURITY.path]]">
@@ -117,7 +126,7 @@ export function getTemplate() {
 
   <template is="dom-if" if="[[enableBundledSecuritySettings_]]">
     <template is="dom-if" if="[[renderView_(
-        routes_.SECURITY, currentRoute, inSearchMode)]]">
+        routes_.SECURITY, currentRoute, inSearchMode)]]" update-when-false>
       <settings-security-page-v2 slot="view"
           id="security" data-parent-view-id="privacy" prefs="{{prefs}}"
           route-path$="[[routes_.SECURITY.path]]">
@@ -127,7 +136,8 @@ export function getTemplate() {
 
   <template is="dom-if" if="[[enableSecurityKeysSubpage_]]">
     <template is="dom-if" if="[[renderView_(
-        routes_.SECURITY_KEYS, currentRoute, inSearchMode)]]">
+        routes_.SECURITY_KEYS, currentRoute, inSearchMode)]]"
+        update-when-false>
       <security-keys-subpage slot="view" id="securityKeys"
         data-parent-view-id="privacy"
         route-path$="[[routes_.SECURITY_KEYS.path]]">
@@ -136,7 +146,8 @@ export function getTemplate() {
   </template>
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS, currentRoute, inSearchMode)]]"
+      update-when-false>
     <settings-site-settings-page slot="view" id="siteSettings"
         data-parent-view-id="privacy" prefs="{{prefs}}"
         route-path$="[[routes_.SITE_SETTINGS.path]]">
@@ -145,7 +156,8 @@ export function getTemplate() {
 
   <template is="dom-if" if="[[enableSafeBrowsingSubresourceFilter_]]">
     <template is="dom-if" if="[[renderView_(
-        routes_.SITE_SETTINGS_ADS, currentRoute, inSearchMode)]]">
+        routes_.SITE_SETTINGS_ADS, currentRoute, inSearchMode)]]"
+        update-when-false>
       <settings-ads-page slot="view" id="siteSettingsAds"
           data-parent-view-id="privacy"
           route-path$="[[routes_.SITE_SETTINGS_ADS.path]]">
@@ -154,14 +166,16 @@ export function getTemplate() {
   </template>
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS_ALL, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS_ALL, currentRoute, inSearchMode)]]"
+      update-when-false>
     <all-sites slot="view" id="siteSettingsAll" data-parent-view-id="privacy"
         route-path$="[[routes_.SITE_SETTINGS_ALL.path]]">
     </all-sites>
   </template>
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS_AR, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS_AR, currentRoute, inSearchMode)]]"
+      update-when-false>
     <settings-ar-page slot="view" id="siteSettingsAr"
         data-parent-view-id="privacy"
         route-path$="[[routes_.SITE_SETTINGS_AR.path]]">
@@ -169,17 +183,18 @@ export function getTemplate() {
   </template>
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS_AUTO_VERIFY, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS_AUTO_VERIFY, currentRoute, inSearchMode)]]"
+      update-when-false>
     <settings-anti-abuse-page slot="view" id="siteSettingsAutoVerify"
         data-parent-view-id="privacy"
         route-path$="[[routes_.SITE_SETTINGS_AUTO_VERIFY.path]]">
     </settings-anti-abuse-page>
   </template>
 
-  <template is="dom-if" if="[[autoPictureInPictureEnabled_]]">
+  <template is="dom-if" if="[[enableAutoPictureInPicture_]]">
     <template is="dom-if" if="[[renderView_(
         routes_.SITE_SETTINGS_AUTO_PICTURE_IN_PICTURE, currentRoute,
-        inSearchMode)]]">
+        inSearchMode)]]" update-when-false>
       <settings-auto-picture-in-picture-page slot="view"
           id="siteSettingsAutoPictureInPicture" data-parent-view-id="privacy"
           route-path$="[[routes_.SITE_SETTINGS_AUTO_PICTURE_IN_PICTURE.path]]">
@@ -188,7 +203,8 @@ export function getTemplate() {
   </template>
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS_AUTOMATIC_DOWNLOADS, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS_AUTOMATIC_DOWNLOADS, currentRoute, inSearchMode)]]"
+      update-when-false>
     <settings-automatic-downloads-page slot="view"
         id="siteSettingsAutomaticDownloads" data-parent-view-id="privacy"
         route-path$="[[routes_.SITE_SETTINGS_AUTOMATIC_DOWNLOADS.path]]">
@@ -197,7 +213,7 @@ export function getTemplate() {
 
   <template is="dom-if" if="[[renderView_(
       routes_.SITE_SETTINGS_AUTOMATIC_FULLSCREEN, currentRoute,
-      inSearchMode)]]">
+      inSearchMode)]]" update-when-false>
     <settings-automatic-full-screen-page slot="view"
         id="siteSettingsAutomaticFullscreen" data-parent-view-id="privacy"
         route-path$="[[routes_.SITE_SETTINGS_AUTOMATIC_FULLSCREEN.path]]">
@@ -205,7 +221,8 @@ export function getTemplate() {
   </template>
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS_BACKGROUND_SYNC, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS_BACKGROUND_SYNC, currentRoute, inSearchMode)]]"
+      update-when-false>
     <settings-background-sync-page slot="view"
         id="siteSettingsBackgroundSync" data-parent-view-id="privacy"
         route-path$="[[routes_.SITE_SETTINGS_BACKGROUND_SYNC.path]]">
@@ -214,7 +231,8 @@ export function getTemplate() {
 
   <template is="dom-if" if="[[enableWebBluetoothNewPermissionsBackend_]]">
     <template is="dom-if" if="[[renderView_(
-        routes_.SITE_SETTINGS_BLUETOOTH_DEVICES, currentRoute, inSearchMode)]]">
+        routes_.SITE_SETTINGS_BLUETOOTH_DEVICES, currentRoute, inSearchMode)]]"
+        update-when-false>
       <settings-bluetooth-devices-page slot="view"
           id="siteSettingsBluetoothDevices"
           route-path$="[[routes_.SITE_SETTINGS_BLUETOOTH_DEVICES.path]]"
@@ -226,7 +244,7 @@ export function getTemplate() {
   <template is="dom-if" if="[[enableExperimentalWebPlatformFeatures_]]">
     <template is="dom-if" if="[[renderView_(
         routes_.SITE_SETTINGS_BLUETOOTH_SCANNING, currentRoute,
-        inSearchMode)]]">
+        inSearchMode)]]" update-when-false>
       <settings-bluetooth-scanning-page slot="view"
           id="siteSettingsBluetoothScanning" data-parent-view-id="privacy"
           route-path$="[[routes_.SITE_SETTINGS_BLUETOOTH_SCANNING.path]]">
@@ -235,17 +253,18 @@ export function getTemplate() {
   </template>
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS_CAMERA, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS_CAMERA, currentRoute, inSearchMode)]]"
+      update-when-false>
     <settings-camera-page slot="view" id="siteSettingsCamera"
         data-parent-view-id="privacy"
         route-path$="[[routes_.SITE_SETTINGS_CAMERA.path]]">
     </settings-camera-page>
   </template>
 
-  <template is="dom-if" if="[[capturedSurfaceControlEnabled_]]">
+  <template is="dom-if" if="[[enableCapturedSurfaceControl_]]">
     <template is="dom-if" if="[[renderView_(
         routes_.SITE_SETTINGS_CAPTURED_SURFACE_CONTROL, currentRoute,
-        inSearchMode)]]">
+        inSearchMode)]]" update-when-false>
       <settings-captured-surface-control-page slot="view"
           id="siteSettingsCapturedSurfaceControl" data-parent-view-id="privacy"
           route-path$="[[routes_.SITE_SETTINGS_CAPTURED_SURFACE_CONTROL.path]]">
@@ -254,7 +273,8 @@ export function getTemplate() {
   </template>
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS_CLIPBOARD, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS_CLIPBOARD, currentRoute, inSearchMode)]]"
+      update-when-false>
     <settings-clipboard-page slot="view"
         id="siteSettingsClipboard" data-parent-view-id="privacy"
         route-path$="[[routes_.SITE_SETTINGS_CLIPBOARD.path]]">
@@ -264,7 +284,8 @@ export function getTemplate() {
   <template is="dom-if" if="[[enableFederatedIdentityApiContentSetting_]]">
     <template is="dom-if" if="[[renderView_(
         routes_.SITE_SETTINGS_FEDERATED_IDENTITY_API, currentRoute,
-        inSearchMode)]]">
+        inSearchMode)]]"
+        update-when-false>
       <settings-federated-identity-api-page slot="view"
           id="siteSettingsFederatedIdentityApi"
           route-path$="[[routes_.SITE_SETTINGS_FEDERATED_IDENTITY_API.path]]"
@@ -274,7 +295,8 @@ export function getTemplate() {
   </template>
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS_FILE_SYSTEM_WRITE, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS_FILE_SYSTEM_WRITE, currentRoute, inSearchMode)]]"
+      update-when-false>
     <settings-filesystem-page slot="view"
         id="siteSettingsFilesystemWrite"
         route-path$="[[routes_.SITE_SETTINGS_FILE_SYSTEM_WRITE.path]]"
@@ -282,10 +304,10 @@ export function getTemplate() {
     </settings-filesystem-page>
   </template>
 
-  <template is="dom-if" if="[[showPersistentPermissions_]]">
+  <template is="dom-if" if="[[enablePersistentPermissions_]]">
     <template is="dom-if" if="[[renderView_(
         routes_.SITE_SETTINGS_FILE_SYSTEM_WRITE_DETAILS, currentRoute,
-        inSearchMode)]]">
+        inSearchMode)]]" update-when-false>
       <file-system-site-details slot="view"
           id="siteSettingsFilesystemWriteDetails"
           route-path$="[[routes_.SITE_SETTINGS_FILE_SYSTEM_WRITE_DETAILS.path]]"
@@ -296,7 +318,8 @@ export function getTemplate() {
 
   <template is="dom-if" if="[[enableHandTrackingContentSetting_]]">
     <template is="dom-if" if="[[renderView_(
-        routes_.SITE_SETTINGS_HAND_TRACKING, currentRoute, inSearchMode)]]">
+        routes_.SITE_SETTINGS_HAND_TRACKING, currentRoute, inSearchMode)]]"
+        update-when-false>
       <settings-hand-tracking-page slot="view" id="siteSettingsHandTracking"
           route-path$="[[routes_.SITE_SETTINGS_HAND_TRACKING.path]]"
           data-parent-view-id="privacy">
@@ -305,7 +328,8 @@ export function getTemplate() {
   </template>
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS_HANDLERS, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS_HANDLERS, currentRoute, inSearchMode)]]"
+      update-when-false>
     <protocol-handlers slot="view" id="siteSettingsHandlers"
         data-parent-view-id="privacy"
         route-path$="[[routes_.SITE_SETTINGS_HANDLERS.path]]"
@@ -315,7 +339,8 @@ export function getTemplate() {
   </template>
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS_HID_DEVICES, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS_HID_DEVICES, currentRoute, inSearchMode)]]"
+      update-when-false>
     <settings-hid-devices-page slot="view" id="siteSettingsHidDevices"
         route-path$="[[routes_.SITE_SETTINGS_HID_DEVICES.path]]"
         data-parent-view-id="privacy">
@@ -323,7 +348,8 @@ export function getTemplate() {
   </template>
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS_IDLE_DETECTION, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS_IDLE_DETECTION, currentRoute, inSearchMode)]]"
+      update-when-false>
     <settings-idle-detection-page slot="view" id="siteSettingsIdleDetection"
         route-path$="[[routes_.SITE_SETTINGS_IDLE_DETECTION.path]]"
         data-parent-view-id="privacy">
@@ -331,7 +357,8 @@ export function getTemplate() {
   </template>
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS_IMAGES, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS_IMAGES, currentRoute, inSearchMode)]]"
+      update-when-false>
     <settings-images-page slot="view" id="siteSettingsImages"
         route-path$="[[routes_.SITE_SETTINGS_IMAGES.path]]"
         data-parent-view-id="privacy">
@@ -339,7 +366,8 @@ export function getTemplate() {
   </template>
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS_MIXEDSCRIPT, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS_MIXEDSCRIPT, currentRoute, inSearchMode)]]"
+      update-when-false>
     <settings-insecure-content-page slot="view"
         id="siteSettingsMixedscript"
         route-path$="[[routes_.SITE_SETTINGS_MIXEDSCRIPT.path]]"
@@ -348,7 +376,8 @@ export function getTemplate() {
   </template>
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS_JAVASCRIPT, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS_JAVASCRIPT, currentRoute, inSearchMode)]]"
+      update-when-false>
     <settings-javascript-page slot="view"
         id="siteSettingsJavascript" data-parent-view-id="privacy"
         route-path$="[[routes_.SITE_SETTINGS_JAVASCRIPT.path]]">
@@ -356,7 +385,8 @@ export function getTemplate() {
   </template>
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS_JAVASCRIPT_OPTIMIZER, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS_JAVASCRIPT_OPTIMIZER, currentRoute, inSearchMode)]]"
+      update-when-false>
     <settings-v8-page slot="view" id="siteSettingsJavascriptOptimizer"
       data-parent-view-id="privacy" prefs="{{prefs}}"
       route-path$="[[routes_.SITE_SETTINGS_JAVASCRIPT_OPTIMIZER.path]]">
@@ -365,7 +395,8 @@ export function getTemplate() {
 
   <template is="dom-if" if="[[enableKeyboardLockPrompt_]]">
     <template is="dom-if" if="[[renderView_(
-        routes_.SITE_SETTINGS_KEYBOARD_LOCK, currentRoute, inSearchMode)]]">
+        routes_.SITE_SETTINGS_KEYBOARD_LOCK, currentRoute, inSearchMode)]]"
+        update-when-false>
       <settings-keyboard-lock-page slot="view" id="siteSettingsKeyboardLock"
           data-parent-view-id="privacy"
           route-path$="[[routes_.SITE_SETTINGS_KEYBOARD_LOCK.path]]">
@@ -376,7 +407,7 @@ export function getTemplate() {
   <template is="dom-if" if="[[enableLocalNetworkAccessSetting_]]">
     <template is="dom-if" if="[[renderView_(
         routes_.SITE_SETTINGS_LOCAL_NETWORK_ACCESS, currentRoute,
-        inSearchMode)]]">
+        inSearchMode)]]" update-when-false>
       <settings-local-network-access-page slot="view"
           id="siteSettingsLocalNetworkAccess" data-parent-view-id="privacy"
           route-path$="[[routes_.SITE_SETTINGS_LOCAL_NETWORK_ACCESS.path]]">
@@ -385,7 +416,8 @@ export function getTemplate() {
   </template>
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS_LOCAL_FONTS, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS_LOCAL_FONTS, currentRoute, inSearchMode)]]"
+      update-when-false>
     <settings-local-fonts-page slot="view" id="siteSettingsLocalFonts"
         data-parent-view-id="privacy"
         route-path$="[[routes_.SITE_SETTINGS_LOCAL_FONTS.path]]">
@@ -393,7 +425,8 @@ export function getTemplate() {
   </template>
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS_LOCATION, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS_LOCATION, currentRoute, inSearchMode)]]"
+      update-when-false>
     <settings-geolocation-page slot="view" id="siteSettingsLocation"
         data-parent-view-id="privacy" prefs="{{prefs}}"
         route-path$="[[routes_.SITE_SETTINGS_LOCATION.path]]">
@@ -401,7 +434,8 @@ export function getTemplate() {
   </template>
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS_MICROPHONE, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS_MICROPHONE, currentRoute, inSearchMode)]]"
+      update-when-false>
     <settings-microphone-page slot="view"
         id="siteSettingsMicrophone" data-parent-view-id="privacy"
         route-path$="[[routes_.SITE_SETTINGS_MICROPHONE.path]]">
@@ -409,7 +443,8 @@ export function getTemplate() {
   </template>
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS_MIDI_DEVICES, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS_MIDI_DEVICES, currentRoute, inSearchMode)]]"
+      update-when-false>
     <settings-midi-devices-page slot="view"
         id="siteSettingsMidiDevices" data-parent-view-id="privacy"
         route-path$="[[routes_.SITE_SETTINGS_MIDI_DEVICES.path]]">
@@ -417,7 +452,8 @@ export function getTemplate() {
   </template>
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS_NOTIFICATIONS, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS_NOTIFICATIONS, currentRoute, inSearchMode)]]"
+      update-when-false>
     <settings-notifications-page slot="view" id="siteSettingsNotifications"
         route-path$="[[routes_.SITE_SETTINGS_NOTIFICATIONS.path]]"
         data-parent-view-id="privacy" prefs="{{prefs}}">
@@ -426,7 +462,8 @@ export function getTemplate() {
 
   <template is="dom-if" if="[[enablePaymentHandlerContentSetting_]]">
     <template is="dom-if" if="[[renderView_(
-        routes_.SITE_SETTINGS_PAYMENT_HANDLER, currentRoute, inSearchMode)]]">
+        routes_.SITE_SETTINGS_PAYMENT_HANDLER, currentRoute, inSearchMode)]]"
+        update-when-false>
       <settings-payment-handler-page slot="view"
           id="siteSettingsPaymentHandler" data-parent-view-id="privacy"
           route-path$="[[routes_.SITE_SETTINGS_PAYMENT_HANDLER.path]]">
@@ -435,7 +472,8 @@ export function getTemplate() {
   </template>
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS_PDF_DOCUMENTS, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS_PDF_DOCUMENTS, currentRoute, inSearchMode)]]"
+      update-when-false>
     <settings-pdf-documents-page slot="view" id="siteSettingsPdfDocuments"
         data-parent-view-id="privacy" prefs="{{prefs}}"
         route-path$="[[routes_.SITE_SETTINGS_PDF_DOCUMENTS.path]]">
@@ -443,7 +481,8 @@ export function getTemplate() {
   </template>
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS_POPUPS, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS_POPUPS, currentRoute, inSearchMode)]]"
+      update-when-false>
     <settings-popups-page slot="view"
         id="siteSettingsPopups" data-parent-view-id="privacy"
         route-path$="[[routes_.SITE_SETTINGS_POPUPS.path]]">
@@ -451,7 +490,8 @@ export function getTemplate() {
   </template>
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS_PROTECTED_CONTENT, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS_PROTECTED_CONTENT, currentRoute, inSearchMode)]]"
+      update-when-false>
     <settings-protected-content-page slot="view"
         id="siteSettingsProtectedContent" data-parent-view-id="privacy"
         prefs="{{prefs}}"
@@ -460,7 +500,8 @@ export function getTemplate() {
   </template>
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS_SENSORS, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS_SENSORS, currentRoute, inSearchMode)]]"
+      update-when-false>
     <settings-sensors-page slot="view"
         id="siteSettingsSensors" data-parent-view-id="privacy"
         route-path$="[[routes_.SITE_SETTINGS_SENSORS.path]]">
@@ -468,7 +509,8 @@ export function getTemplate() {
   </template>
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS_SERIAL_PORTS, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS_SERIAL_PORTS, currentRoute, inSearchMode)]]"
+      update-when-false>
     <settings-serial-ports-page slot="view"
         id="siteSettingsSerialPorts" data-parent-view-id="privacy"
         route-path$="[[routes_.SITE_SETTINGS_SERIAL_PORTS.path]]">
@@ -478,7 +520,8 @@ export function getTemplate() {
 
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS_SOUND, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS_SOUND, currentRoute, inSearchMode)]]"
+      update-when-false>
     <settings-sound-page slot="view"
         id="siteSettingsSound" data-parent-view-id="privacy"
         prefs="{{prefs}}" route-path$="[[routes_.SITE_SETTINGS_SOUND.path]]">
@@ -486,7 +529,8 @@ export function getTemplate() {
   </template>
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS_SITE_DATA, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS_SITE_DATA, currentRoute, inSearchMode)]]"
+      update-when-false>
     <settings-site-data slot="view" id="siteSettingsSiteData"
         data-parent-view-id="privacy" prefs="{{prefs}}"
         route-path$="[[routes_.SITE_SETTINGS_SITE_DATA.path]]">
@@ -494,15 +538,17 @@ export function getTemplate() {
   </template>
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS_SITE_DETAILS, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS_SITE_DETAILS, currentRoute, inSearchMode)]]"
+      update-when-false>
     <site-details slot="view" id="siteSettingsSiteDetails"
-        data-parent-view-id="privacy"
+        data-parent-view-id="privacy" prefs="{{prefs}}"
         route-path$="[[routes_.SITE_SETTINGS_SITE_DETAILS.path]]">
     </site-details>
   </template>
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS_STORAGE_ACCESS, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS_STORAGE_ACCESS, currentRoute, inSearchMode)]]"
+      update-when-false>
     <settings-storage-access-page slot="view" id="siteSettingsStorageAccess"
         data-parent-view-id="privacy"
         route-path$="[[routes_.SITE_SETTINGS_STORAGE_ACCESS.path]]">
@@ -510,7 +556,8 @@ export function getTemplate() {
   </template>
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS_USB_DEVICES, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS_USB_DEVICES, currentRoute, inSearchMode)]]"
+      update-when-false>
     <settings-usb-devices-page slot="view" id="siteSettingsUsbDevices"
         route-path$="[[routes_.SITE_SETTINGS_USB_DEVICES.path]]"
         data-parent-view-id="privacy">
@@ -518,7 +565,8 @@ export function getTemplate() {
   </template>
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS_VR, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS_VR, currentRoute, inSearchMode)]]"
+      update-when-false>
     <settings-vr-page slot="view" id="siteSettingsVr" data-parent-view-id="privacy"
       route-path$="[[routes_.SITE_SETTINGS_VR.path]]">
     </settings-vr-page>
@@ -527,7 +575,7 @@ export function getTemplate() {
   <template is="dom-if" if="[[enableWebAppInstallation_]]">
     <template is="dom-if" if="[[renderView_(
         routes_.SITE_SETTINGS_WEB_APP_INSTALLATION, currentRoute,
-        inSearchMode)]]">
+        inSearchMode)]]" update-when-false>
       <settings-web-applications-page slot="view"
           id="siteSettingsWebAppInstallation" data-parent-view-id="privacy"
           route-path$="[[routes_.SITE_SETTINGS_WEB_APP_INSTALLATION.path]]">
@@ -537,7 +585,8 @@ export function getTemplate() {
 
   <template is="dom-if" if="[[enableWebPrintingContentSetting_]]">
     <template is="dom-if" if="[[renderView_(
-        routes_.SITE_SETTINGS_WEB_PRINTING, currentRoute, inSearchMode)]]">
+        routes_.SITE_SETTINGS_WEB_PRINTING, currentRoute, inSearchMode)]]"
+        update-when-false>
       <settings-web-printing-page slot="view"
           id="siteSettingsWebPrinting" data-parent-view-id="privacy"
           route-path$="[[routes_.SITE_SETTINGS_WEB_PRINTING.path]]">
@@ -546,7 +595,8 @@ export function getTemplate() {
   </template>
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS_WINDOW_MANAGEMENT, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS_WINDOW_MANAGEMENT, currentRoute, inSearchMode)]]"
+      update-when-false>
     <settings-window-management-page slot="view"
         id="siteSettingsWindowManagement" data-parent-view-id="privacy"
         route-path$="[[routes_.SITE_SETTINGS_WINDOW_MANAGEMENT.path]]">
@@ -554,7 +604,8 @@ export function getTemplate() {
   </template>
 
   <template is="dom-if" if="[[renderView_(
-      routes_.SITE_SETTINGS_ZOOM_LEVELS, currentRoute, inSearchMode)]]">
+      routes_.SITE_SETTINGS_ZOOM_LEVELS, currentRoute, inSearchMode)]]"
+      update-when-false>
     <zoom-levels slot="view" id="siteSettingsZoomLevels"
         data-parent-view-id="privacy"
         route-path$="[[routes_.SITE_SETTINGS_ZOOM_LEVELS.path]]">
