@@ -260,7 +260,6 @@ const kSections = {
     angleFeatures: ['ANGLE Features', 'ul'],
     dawnInfo: ['Dawn Info', 'ul'],
     compositorInfo: ['Compositor Information', 'div'],
-    gpuMemoryBufferInfo: ['GpuMemoryBuffers Status', 'div'],
     displayInfo: ['Display(s) Information', 'div'],
     videoAccelerationInfo: ['Video Acceleration Information', 'div'],
     vulkanInfo: ['Vulkan Information', 'div'],
@@ -465,7 +464,6 @@ export class InfoViewElement extends CustomElement {
             }
             this.setTable_(sections.basicInfo, gpuInfo.basicInfo);
             this.setTable_(sections.compositorInfo, gpuInfo.compositorInfo);
-            this.setTable_(sections.gpuMemoryBufferInfo, gpuInfo.gpuMemoryBufferInfo);
             this.setTable_(sections.displayInfo, gpuInfo.displayInfo);
             this.setTable_(sections.videoAccelerationInfo, gpuInfo.videoAcceleratorsInfo);
             this.updateSectionList_(sections.angleFeatures, gpuInfo.ANGLEFeatures, angleFeature => this.createAngleFeatureEl_(angleFeature));
@@ -541,7 +539,6 @@ export class InfoViewElement extends CustomElement {
             'protected_video_decode': 'Hardware Protected Video Decode',
             'surface_control': 'Surface Control',
             'vpx_decode': 'VPx Video Decode',
-            'webgl2': 'WebGL2',
             'canvas_oop_rasterization': 'Canvas out-of-process rasterization',
             'raw_draw': 'Raw Draw',
             'video_encode': 'Video Encode',
