@@ -14,6 +14,7 @@ def root(context, missing=missing):
     l_0_for_blink = resolve('for_blink')
     l_0_disallow_interfaces = resolve('disallow_interfaces')
     l_0_uses_interfaces = resolve('uses_interfaces')
+    l_0_uses_message_size_estimator = resolve('uses_message_size_estimator')
     l_0_disallow_native_types = resolve('disallow_native_types')
     l_0_uses_native_types = resolve('uses_native_types')
     l_0_extra_public_headers = resolve('extra_public_headers')
@@ -166,7 +167,11 @@ def root(context, missing=missing):
     yield '\n\n'
     if ((not (undefined(name='disallow_interfaces') if l_0_disallow_interfaces is missing else l_0_disallow_interfaces)) and (undefined(name='uses_interfaces') if l_0_uses_interfaces is missing else l_0_uses_interfaces)):
         pass
-        yield '#include "mojo/public/cpp/bindings/lib/control_message_handler.h"\n#include "mojo/public/cpp/bindings/lib/message_size_estimator.h"\n#include "mojo/public/cpp/bindings/raw_ptr_impl_ref_traits.h"'
+        yield '#include "mojo/public/cpp/bindings/lib/control_message_handler.h"'
+        if (undefined(name='uses_message_size_estimator') if l_0_uses_message_size_estimator is missing else l_0_uses_message_size_estimator):
+            pass
+            yield '\n#include "mojo/public/cpp/bindings/lib/message_size_estimator.h"'
+        yield '\n#include "mojo/public/cpp/bindings/raw_ptr_impl_ref_traits.h"'
     yield '\n\n'
     if ((not (undefined(name='disallow_native_types') if l_0_disallow_native_types is missing else l_0_disallow_native_types)) and (undefined(name='uses_native_types') if l_0_uses_native_types is missing else l_0_uses_native_types)):
         pass
@@ -351,4 +356,4 @@ def root(context, missing=missing):
     yield str((undefined(name='header_guard') if l_0_header_guard is missing else l_0_header_guard))
 
 blocks = {}
-debug_info = '5=96&8=111&10=114&11=119&12=123&16=129&17=131&26=133&38=140&39=142&40=144&42=146&43=149&44=152&46=157&50=160&62=167&68=171&73=174&74=178&77=181&78=184&81=186&87=190&93=193&94=197&98=199&99=202&100=205&101=207&105=211&107=212&110=215&111=219&115=223&116=227&120=231&121=235&125=239&126=243&130=247&131=255&138=260&139=264&140=267&147=273&148=277&152=282&153=286&154=289&158=294&159=298&162=302&163=305&164=308&168=313&173=315&174=318&175=321&180=325&181=327&182=331&187=335&189=338&190=345&197=351'
\ No newline at end of file
+debug_info = '5=97&8=112&10=115&11=120&12=124&16=130&17=132&26=134&38=141&39=143&40=145&42=147&43=150&44=153&46=158&50=161&62=168&64=171&70=176&75=179&76=183&79=186&80=189&83=191&89=195&95=198&96=202&100=204&101=207&102=210&103=212&107=216&109=217&112=220&113=224&117=228&118=232&122=236&123=240&127=244&128=248&132=252&133=260&140=265&141=269&142=272&149=278&150=282&154=287&155=291&156=294&160=299&161=303&164=307&165=310&166=313&170=318&175=320&176=323&177=326&182=330&183=332&184=336&189=340&191=343&192=350&199=356'
\ No newline at end of file
